#!/bin/bash -e

DEV_FILES_DIR="container/dev"
RESOURCES_DIR="resources"
APP_DIR="app"
APP_NAME=$(cd $APP_DIR && yq -r '.name' pubspec.yaml)
IMAGE_NAME="${APP_NAME}_dev_image"
IMAGE_ARCHIVE_FILE="${IMAGE_NAME}.tar"
IMAGE_TAG="latest"
DESC_FILE="${IMAGE_NAME}.desc"
SSH_DIR=$(cd $(dirname "$0")/../config/ssh; pwd)
TEMPLATE_DIR="template"
CONF_TEMPLATE_FILE="container.conf.tmpl"
ROOT_CONF_DIR="root/etc/atmark/containers"

gen_swu() {
    version=1

    if [ -e "$DESC_FILE" ]; then
        version=$(awk -F= '$1 == "swdesc_option version" { print $2 + 1 }' "$DESC_FILE")
        mv -f "$DESC_FILE" "$DESC_FILE".old
    fi
    cat > "$DESC_FILE" <<EODESC
swdesc_option version=${version:-1}

swdesc_files --extra-os root
swdesc_embed_container "${IMAGE_NAME}.tar"
EODESC

mkswu "$DESC_FILE"
}

scripts/build_base_container_image.sh

(
    cd "$DEV_FILES_DIR"
    rm -rf "$IMAGE_ARCHIVE_FILE"

    if [[ ! -e "$SSH_DIR/id_rsa.pub" ]]; then
        echo "id_rsa.pub not found." >&2
        echo "Please do [Terminal]->[Run Tasks...]->[Setup envronment] first on the VSCode menu." >&2
        exit 1
    fi

    cat "$SSH_DIR/id_rsa.pub" > "$RESOURCES_DIR/root/.ssh/authorized_keys"

    sed -e "s/{{IMAGE_NAME}}/$IMAGE_NAME/g" -e "s/{{IMAGE_TAG}}/$IMAGE_TAG/g" "$TEMPLATE_DIR"/"$CONF_TEMPLATE_FILE" \
        > "$ROOT_CONF_DIR"/"$APP_NAME".conf

    if ! podman image inspect "$IMAGE_NAME" > /dev/null; then
        podman build -t "$IMAGE_NAME":"$IMAGE_TAG" .
    fi
    podman save -o "$IMAGE_ARCHIVE_FILE" "localhost/$IMAGE_NAME":"$IMAGE_TAG"

    gen_swu
)
