#!/bin/bash -e

BIN_DIR="usr/bin"
APP_INSTALL_DIR="${BIN_DIR}/share"
APP_DIR="app"
BUNDLE_FILES_DIR="$APP_DIR/build/elinux/arm64/release/bundle"
REL_FILES_DIR="container/release"
RESOURCES_DIR="resources"
APP_NAME=$(cd $APP_DIR && yq -r '.name' pubspec.yaml)
IMAGE_NAME="${APP_NAME}_rel_image"
IMAGE_ARCHIVE_FILE="${IMAGE_NAME}.tar"
IMAGE_TAG="latest"
DESC_FILE="${IMAGE_NAME}.desc"
TEMPLATE_DIR="template"
CONF_TEMPLATE_FILE="container.conf.tmpl"
ROOT_CONF_DIR="root/etc/atmark/containers"
APP_START_TEMPLATE_FILE="app_start.tmpl"

gen_swu() {
    version=1

    if [ -e "$DESC_FILE" ]; then
        version=$(awk -F= '$1 == "swdesc_option version" { print $2 + 1 }' "$DESC_FILE")
        mv -f "$DESC_FILE" "$DESC_FILE".old
    fi
    cat > "$DESC_FILE" <<EODESC
swdesc_option version=${version:-1}

swdesc_files --extra-os root
swdesc_embed_container "${IMAGE_NAME}.tar"
EODESC

mkswu "$DESC_FILE"
}

scripts/build_base_container_image.sh

(
    if [ ! -e $BUNDLE_FILES_DIR ]; then
        echo "$BUNDLE_FILES_DIR not found." >&2
        echo "Please do [Terminal]->[Run Tasks...]->[App build for release] first on the VSCode menu." >&2
        exit 1
    fi

    mkdir -p "$REL_FILES_DIR/$RESOURCES_DIR/$APP_INSTALL_DIR"
    cp -r "$BUNDLE_FILES_DIR" "$REL_FILES_DIR/$RESOURCES_DIR/$APP_INSTALL_DIR"
    cd "$REL_FILES_DIR"
    rm -rf "$IMAGE_ARCHIVE_FILE"

    sed -e "s/{{IMAGE_NAME}}/$IMAGE_NAME/g" -e "s/{{IMAGE_TAG}}/$IMAGE_TAG/g" -e "s/{{APP_NAME}}/$APP_NAME/g" \
        "$TEMPLATE_DIR"/"$CONF_TEMPLATE_FILE" > "$ROOT_CONF_DIR"/"$APP_NAME".conf
    sed -e "s/{{APP_NAME}}/$APP_NAME/g" "$TEMPLATE_DIR"/"$APP_START_TEMPLATE_FILE" \
        > "$RESOURCES_DIR/$BIN_DIR/$APP_NAME"
    chmod +x "$RESOURCES_DIR/$BIN_DIR/$APP_NAME"

    if ! podman image inspect "$IMAGE_NAME" > /dev/null; then
        podman build -t "$IMAGE_NAME":"$IMAGE_TAG" .
    fi
    podman save -o "$IMAGE_ARCHIVE_FILE" "localhost/$IMAGE_NAME":"$IMAGE_TAG"

    gen_swu
)
